==> redturtle.prenotazioni-2.3.2-py3-none-any.whl: redturtle/prenotazioni/restapi/services/bookings/search.py <==
# -*- coding: utf-8 -*-
from DateTime import DateTime
from plone import api
from plone.restapi.services import Service
from zExceptions import Unauthorized
from zope.component import getMultiAdapter
from zope.interface import implementer
from zope.publisher.interfaces import IPublishTraverse

from redturtle.prenotazioni.interfaces import ISerializeToPrenotazioneSearchableItem


@implementer(IPublishTraverse)
class BookingsSearch(Service):
    """
    Preonotazioni search view
    """

    def publishTraverse(self, request, userid):
        if not request.get("userid", None):
            request.set("userid", userid)
        return self

    def query(self):
        query = {
            "portal_type": "Prenotazione",
            "sort_on": "Date",
            "sort_order": "reverse",
        }

        if api.user.is_anonymous():
            raise Unauthorized("You must be logged in to perform this action")
        elif api.user.has_permission(
            "redturtle.prenotazioni: search prenotazioni", obj=self.context
        ):
            userid = self.request.get("userid", None)
        else:
            userid = api.user.get_current().getUserId()

        if userid:
            query["fiscalcode"] = userid.upper()

        start_date = self.request.get("from", None)
        end_date = self.request.get("to", None)
        gate = self.request.get("gate", None)
        booking_type = self.request.get("booking_type", None)
        SearchableText = self.request.get("SearchableText", None)
        review_state = self.request.get("review_state", None)

        # 2023-01-01 -> 2023-01-01T00:00:00
        if start_date and len(start_date) == 10:
            start_date = f"{start_date}T00:00:00"
        if end_date and len(end_date) == 10:
            end_date = f"{end_date}T23:59:59"
        if start_date or end_date:
            query["Date"] = {
                "query": [DateTime(i) for i in [start_date, end_date] if i],
                "range": f"{start_date and 'min' or ''}{start_date and end_date and ':' or ''}{end_date and 'max' or ''}",  # noqa: E501
            }

        if gate:
            query["Subject"] = "Gate: {}".format(gate)

        if booking_type:
            query["booking_type"] = booking_type

        if SearchableText:
            query["SearchableText"] = SearchableText

        if review_state:
            query["review_state"] = review_state

        return query

    def reply(self):
        fullobjects = self.request.form.get("fullobjects", False) == "1"
        response = {"id": self.context.absolute_url() + "/@bookings"}
        query = self.query()
        # XXX: `fullobjects` the correct behavior should be to use different serializers
        response["items"] = [
            getMultiAdapter(
                (i.getObject(), self.request),
                ISerializeToPrenotazioneSearchableItem,
            )(fullobjects=fullobjects)
            for i in api.portal.get_tool("portal_catalog")(**query)
        ]

        response["items_total"] = len(response["items"])

        return response


class BookingsSearchFolder(BookingsSearch):
    def query(self):
        query = super(BookingsSearchFolder, self).query()
        query["path"] = "/".join(self.context.getPhysicalPath())
        return query

==> redturtle.prenotazioni-2.5.0-py3-none-any.whl: redturtle/prenotazioni/restapi/services/bookings/search.py <==
# -*- coding: utf-8 -*-
import logging
from DateTime import DateTime
from plone import api
from plone.restapi.services import Service
from zExceptions import Unauthorized
from zope.component import getMultiAdapter
from zope.interface import implementer
from zope.publisher.interfaces import IPublishTraverse

from redturtle.prenotazioni.interfaces import ISerializeToPrenotazioneSearchableItem


logger = logging.getLogger(__name__)


@implementer(IPublishTraverse)
class BookingsSearch(Service):
    """
    Preonotazioni search view
    """

    def publishTraverse(self, request, userid):
        if not request.get("userid", None):
            request.set("userid", userid)
        return self

    def query(self):
        sort_on = self.request.get("sort_on") or "Date"
        sort_order = self.request.get("sort_order") or "descending"
        query = {
            "portal_type": "Prenotazione",
            "sort_on": sort_on,
            "sort_order": sort_order,
        }

        if api.user.is_anonymous():
            raise Unauthorized("You must be logged in to perform this action")
        elif api.user.has_permission(
            "redturtle.prenotazioni: search prenotazioni", obj=self.context
        ):
            userid = self.request.get("userid", None)
        else:
            userid = api.user.get_current().getUserId()

        if userid:
            query["fiscalcode"] = userid.upper()

        start_date = self.request.get("from", None)
        end_date = self.request.get("to", None)
        gate = self.request.get("gate", None)
        booking_type = self.request.get("booking_type", None)
        SearchableText = self.request.get("SearchableText", None)
        review_state = self.request.get("review_state", None)
        modified_after = self.request.get("modified_after", None)
        # 2023-01-01 -> 2023-01-01T00:00:00
        if start_date and len(start_date) == 10:
            start_date = f"{start_date}T00:00:00"
        if end_date and len(end_date) == 10:
            end_date = f"{end_date}T23:59:59"
        if start_date or end_date:
            query["Date"] = {
                "query": [DateTime(i) for i in [start_date, end_date] if i],
                "range": f"{start_date and 'min' or ''}{start_date and end_date and ':' or ''}{end_date and 'max' or ''}",  # noqa: E501
            }
        if modified_after:
            query["modified"] = {"query": DateTime(modified_after), "range": "min"}
        if gate:
            query["Subject"] = "Gate: {}".format(gate)

        if booking_type:
            query["booking_type"] = booking_type

        if SearchableText:
            query["SearchableText"] = SearchableText

        if review_state:
            query["review_state"] = review_state

        return query

    def reply(self):
        fullobjects = self.request.form.get("fullobjects", False) == "1"
        response = {"id": self.context.absolute_url() + "/@bookings"}
        query = self.query()
        # XXX: `fullobjects` the correct behavior should be to use different serializers
        items = []
        for i in api.portal.get_tool("portal_catalog")(**query):
            # TEMP: errors with broken catalog entries
            try:
                items.append(
                    getMultiAdapter(
                        (i.getObject(), self.request),
                        ISerializeToPrenotazioneSearchableItem,
                    )(fullobjects=fullobjects)
                )
            except:  # noqa: E722
                logger.exception("error with %s", i.getPath())
        response["items"] = items
        response["items_total"] = len(response["items"])
        return response


class BookingsSearchFolder(BookingsSearch):
    def query(self):
        query = super(BookingsSearchFolder, self).query()
        query["path"] = "/".join(self.context.getPhysicalPath())
        return query
